## Links

- Documentation: [warn-scraper.readthedocs.io](https://warn-scraper.readthedocs.io)
- Repository: [github.com/biglocalnews/warn-scraper](https://github.com/biglocalnews/warn-scraper)
- Packaging: [pypi.org/project/warn-scraper](https://pypi.org/project/warn-scraper/)

## About

The project is sponsored by [Big Local News](https://biglocalnews.org/#/about), a program at Stanford University that collects data for impactful journalism. The code is maintained by Stanford Lecturer [Serdar Tumgoren](https://comm.stanford.edu/faculty-tumgoren/) and [Ben Welsh](https://palewi.re/who-is-ben-welsh/), a visiting data journalist from the Los Angeles Times.
